diff --git a/core/modules/field_ui/src/Tests/EntityDisplayTest.php b/core/modules/field_ui/src/Tests/EntityDisplayTest.php
index 1c9332b..f0164ed 100644
--- a/core/modules/field_ui/src/Tests/EntityDisplayTest.php
+++ b/core/modules/field_ui/src/Tests/EntityDisplayTest.php
@@ -157,7 +157,7 @@ public function testEntityGetDisplay() {
   }
 
   /**
    * Tests the behavior of a field component within an entity display object.
    */
   public function testExtraFieldComponent() {
     entity_test_create_bundle('bundle_with_extra_fields');
@@ -170,17 +170,36 @@ public function testExtraFieldComponent() {
     // Check that the default visibility taken into account for extra fields
     // unknown in the display.
     $this->assertEqual($display->getComponent('display_extra_field'), array('weight' => 5));
-    $this->assertNull($display->getComponent('display_extra_field_hidden'));
-
     // Check that setting explicit options overrides the defaults.
     $display->removeComponent('display_extra_field');
-    $display->setComponent('display_extra_field_hidden', array('weight' => 10));
     $this->assertNull($display->getComponent('display_extra_field'));
-    $this->assertEqual($display->getComponent('display_extra_field_hidden'), array('weight' => 10, 'settings' => array(), 'third_party_settings' => array()));
   }
 
   /**
-   * Tests the behavior of a field component within an entity display object.
+   * Tests a non-visible field component within an entity display object.
+   */
+  public function testNonVisibleExtraFieldComponent() {
+    entity_test_create_bundle('bundle_with_extra_fields');
+    $display = EntityViewDisplay::create(array(
+      'targetEntityType' => 'entity_test',
+      'bundle' => 'bundle_with_extra_fields',
+      'mode' => 'default',
+    ));
+
+    // Check that the default visibility taken into account for extra fields
+    // unknown in the display.
+    $this->assertNull($display->getComponent('display_extra_field_hidden'));
+
+    // Check that setting explicit options overrides the defaults.
+    $display->setComponent('display_extra_field_hidden', ['weight' => 10]);
+    $this->assertEqual(
+      $display->getComponent('display_extra_field_hidden'),
+      ['weight' => 10, 'settings' => [], 'third_party_settings' => []]
+    );
+  }
+
+  /**
+   * Tests complex field component behavior within an entity display object.
    */
   public function testFieldComponent() {
     $field_name = 'test_field';
@@ -157,7 +157,7 @@ public function testEntityGetDisplay() {
 
   /**
-   * Tests the behavior of a field component within an entity display object.
+   * Tests a visible field component within an entity display object.
    */
   public function testExtraFieldComponent() {
